# Inmarsat FieldEdge Utilities

Provides a common logging format and facility,
and a common MQTT client that automatically connects.

[Docmentation](https://inmarsat-enterprise.github.io/fieldedge-utilities/)
